# Generated by Django 2.2.23 on 2021-05-19 15:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0018_page_version_publication_date'),
        ('pages', '0013_auto_20210326_1533'),
    ]

    operations = [
    ]
