# Generated by Django 2.2.9 on 2020-11-11 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0016_auto_20201102_2021'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='version_name',
            field=models.CharField(blank=True, help_text='Used to identify this version in the admin', max_length=100, null=True, verbose_name='draft name'),
        ),
    ]
