# Generated by Django 2.2.9 on 2020-10-13 15:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0012_auto_20201009_1558'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='page',
            name='is_content_object',
        ),
        migrations.AddField(
            model_name='page',
            name='version',
            field=models.IntegerField(default=1),
        ),
        migrations.AddField(
            model_name='page',
            name='version_for',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='version_set', to='pages.Page'),
        ),
    ]
